@@ -1,10 +1,9 @@
-from mitosheet.sheet_functions.types.utils import get_mito_type
-from mitosheet.save_utils import read_analysis
-from mitosheet.steps import STEP_TYPE_TO_STEP
+from mitosheet.saved_analyses import read_and_upgrade_analysis
+from mitosheet.step_performers import STEP_TYPE_TO_STEP_PERFORMER
 import json
 
 
-def get_saved_analysis_description(event, wsc):
+def get_saved_analysis_description(event, steps_manager):
     """
     Gets the description of the steps in the saved analysis, and sends
     it back to the frontend
@@ -13,28 +12,23 @@ def get_saved_analysis_description(event, wsc):
     not exist.
     """
     analysis_name = event['analysis_name']
-    analysis_steps = read_analysis(analysis_name)
+    analysis_steps = read_and_upgrade_analysis(analysis_name)
     
     try:
         if analysis_steps is None:
             return ''
         
         analysis_descriptions = []
-        for step_number in analysis_steps['steps']:
-
-            step = analysis_steps['steps'][step_number]
-            STEP_OBJ = STEP_TYPE_TO_STEP[step['step_type']]
-
-            # Create the step param object
-            params = {key: value for key, value in step.items() if key in STEP_OBJ['params']}
+        for step_data in analysis_steps['steps_data']:
+            step_performer = STEP_TYPE_TO_STEP_PERFORMER[step_data['step_type']]
 
             # Generate the step description
-            step_description = STEP_OBJ['describe'](
-                **params
+            step_description = step_performer.describe(
+                **step_data['params']
             )
 
             analysis_descriptions.append({
-                'step_type': step['step_type'],
+                'step_type': step_data['step_type'],
                 'step_description': step_description
             })
 
