@@ -8,6 +8,7 @@
 This file contains helpful functions and classes for testing operations.
 """
 
+from mitosheet.column_headers import get_column_header_id, get_column_header_ids
 from typing import List
 from mitosheet.utils import get_new_id
 import pandas as pd
@@ -34,6 +35,10 @@ class MitoWidgetTestWrapper:
         # we don't have to change tests if we update comments
         return transpile(self.mito_widget.steps_manager, add_comments=False)['code']
 
+    @property
+    def dfs(self):
+        return self.mito_widget.steps_manager.dfs
+
     def add_column(self, sheet_index: int, column_header: str, column_header_index=-1):
         """
         Adds a column.
@@ -65,6 +70,11 @@ class MitoWidgetTestWrapper:
         if add_column:
             self.add_column(sheet_index, column_header)
 
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -74,7 +84,7 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_header': column_header,
+                    'column_id': column_id,
                     'new_formula': formula,
                 }
             }
@@ -90,6 +100,24 @@ class MitoWidgetTestWrapper:
             merge_key_two,
             selected_columns_two
         ):
+
+        merge_key_column_id_one = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index_one,
+            merge_key_one
+        )
+        merge_key_column_id_two = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index_two,
+            merge_key_two
+        )
+        selected_column_ids_one = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index_one, column_header)
+            for column_header in selected_columns_one
+        ]
+        selected_column_ids_two = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index_two, column_header)
+            for column_header in selected_columns_two
+        ]
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -100,11 +128,11 @@ class MitoWidgetTestWrapper:
                 'params': {
                     'how': how,
                     'sheet_index_one': sheet_index_one,
-                    'merge_key_one': merge_key_one,
-                    'selected_columns_one': selected_columns_one,
+                    'merge_key_column_id_one': merge_key_column_id_one,
+                    'selected_column_ids_one': selected_column_ids_one,
                     'sheet_index_two': sheet_index_two,
-                    'merge_key_two': merge_key_two,
-                    'selected_columns_two': selected_columns_two
+                    'merge_key_column_id_two': merge_key_column_id_two,
+                    'selected_column_ids_two': selected_column_ids_two
                 }
             }
         )
@@ -118,6 +146,20 @@ class MitoWidgetTestWrapper:
             destination_sheet_index=None,
             step_id=None
         ):
+
+        rows_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in pivot_rows
+        ]
+        columns_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in pivot_columns
+        ]
+        values_column_ids_map = {
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header): value
+            for column_header, value in values.items()
+        }
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -127,9 +169,9 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id() if step_id is None else step_id,
                 'params': {
                     'sheet_index': sheet_index,
-                    'pivot_rows': pivot_rows,
-                    'pivot_columns': pivot_columns,
-                    'values': values,
+                    'pivot_rows_column_ids': rows_ids,
+                    'pivot_columns_column_ids': columns_ids,
+                    'values_column_ids_map': values_column_ids_map,
                     'destination_sheet_index': destination_sheet_index
                 }
             }
@@ -138,12 +180,18 @@ class MitoWidgetTestWrapper:
     def filter(
             self, 
             sheet_index, 
-            column,
+            column_header,
             operator,
             type_,
             condition, 
             value
         ):
+
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -153,7 +201,7 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_header': column,
+                    'column_id': column_id,
                     'operator': operator,
                     'filters': [{
                         'type': type_,
@@ -167,10 +215,17 @@ class MitoWidgetTestWrapper:
     def filters(
             self, 
             sheet_index, 
-            column,
+            column_header,
             operator,
             filters
         ):
+
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -180,7 +235,7 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_header': column,
+                    'column_id': column_id,
                     'operator': operator,
                     'filters': filters
                 }
@@ -190,9 +245,15 @@ class MitoWidgetTestWrapper:
     def sort(
             self, 
             sheet_index, 
-            column,
+            column_header,
             sort_direction
         ):
+
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -202,7 +263,7 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_header': column,
+                    'column_id': column_id,
                     'sort_direction': sort_direction
                 }
             }
@@ -214,6 +275,12 @@ class MitoWidgetTestWrapper:
             column_header, 
             new_column_index
         ):
+
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -223,13 +290,19 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_header': column_header,
+                    'column_id': column_id,
                     'new_column_index': new_column_index
                 }
             }
         )
 
     def rename_column(self, sheet_index: int, old_column_header: str, new_column_header):
+
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            old_column_header
+        )
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -239,13 +312,18 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'old_column_header': old_column_header,
+                    'column_id': column_id,
                     'new_column_header': new_column_header
                 }
             }
         )
 
     def delete_column(self, sheet_index: int, column_header: str):
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -255,12 +333,18 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_header': column_header
+                    'column_id': column_id,
                 }
             }
         )
 
     def change_column_dtype(self, sheet_index: int, column_header: str, new_dtype: str):
+
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
         self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -270,7 +354,7 @@ class MitoWidgetTestWrapper:
                 'step_id': get_new_id(),
                 'params': {
                     'sheet_index': sheet_index,
-                    'column_header': column_header,
+                    'column_id': column_id,
                     'new_dtype': new_dtype
                 }
             }
@@ -290,6 +374,20 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    def bulk_old_rename(self, move_to_deprecated_id_algorithm=False):
+        self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'old_rename_only_use_this_in_testing',
+                'step_id': get_new_id(),
+                'params': {
+                    'move_to_deprecated_id_algorithm': move_to_deprecated_id_algorithm
+                }
+            }
+        )
+
     
     def undo(self):
         self.mito_widget.receive_message(
@@ -400,6 +498,28 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    def set_cell_value(self, sheet_index, column_header, row_index, new_value):
+        column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+            sheet_index,
+            column_header
+        )
+
+        self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'set_cell_value_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_id': column_id,
+                    'row_index': row_index,
+                    'new_value': str(new_value)
+                }
+            }
+        )
+
     def replay_analysis(self, analysis_name, import_summaries=None, clear_existing_analysis=False):
         self.mito_widget.receive_message(
             self.mito_widget,
@@ -429,9 +549,24 @@ class MitoWidgetTestWrapper:
         Gets the formula for a given column. Returns an empty
         string if nothing exists.
         """
-        if column_header not in self.mito_widget.column_spreadsheet_code[sheet_index]:
+        column_id = self.mito_widget.steps_manager.curr_step.post_state.column_ids.get_column_id_by_header(
+            sheet_index, column_header
+        )
+        if column_id not in self.mito_widget.steps_manager.curr_step.column_spreadsheet_code[sheet_index]:
             return ''
-        return self.mito_widget.column_spreadsheet_code[sheet_index][column_header]
+        return self.mito_widget.steps_manager.curr_step.column_spreadsheet_code[sheet_index][column_id]
+
+    def get_python_formula(self, sheet_index: int, column_header: str):
+        """
+        Gets the formula for a given column. Returns an empty
+        string if nothing exists.
+        """
+        column_id = self.mito_widget.steps_manager.curr_step.post_state.column_ids.get_column_id_by_header(
+            sheet_index, column_header
+        )
+        if column_id not in self.mito_widget.steps_manager.curr_step.column_python_code[sheet_index]:
+            return ''
+        return self.mito_widget.steps_manager.curr_step.column_python_code[sheet_index][column_id]
 
     def get_value(self, sheet_index: int, column_header: str, row: int):
         """
@@ -452,6 +587,7 @@ class MitoWidgetTestWrapper:
         if as_list:
             return self.mito_widget.steps_manager.dfs[sheet_index][column_header].tolist()
         return self.mito_widget.steps_manager.dfs[sheet_index][column_header]
+        
 
 def create_mito_wrapper(sheet_one_A_data, sheet_two_A_data=None) -> MitoWidgetTestWrapper:
     """
